nx.geometry.Line - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.geometry.Line Class

Module: nx.geometry

Mathematics Line class

- Index
- Methods

## Item Index

### Methods

- angle
- center
- clone
- general
- intersection
- length
- negate
- normal
- pad
- pedal
- rotate
- slope
- squaredLength
- translate

## Methods

### `angle`

()

#### Returns:

:

### `center`

() nx.geometry.Vector

#### Returns:

nx.geometry.Vector:

### `clone`

() nx.geometry.Line

#### Returns:

nx.geometry.Line:

### `general`

() Array

#### Returns:

Array:

### `intersection`

(

- `l`

)
nx.geometry.Vector

#### Parameters:

- `l` nx.geometry.Line

#### Returns:

nx.geometry.Vector:

### `length`

()

#### Returns:

:

### `negate`

() nx.geometry.Line

#### Returns:

nx.geometry.Line:

### `normal`

() nx.geometry.Vector

#### Returns:

nx.geometry.Vector:

### `pad`

(

- `a`
- `b`

)
nx.geometry.Line

#### Parameters:

- `a` nx.geometry.Vector
- `b` nx.geometry.Vector

#### Returns:

nx.geometry.Line:

### `pedal`

(

- `v`

)
nx.geometry.Vector

#### Parameters:

- `v` nx.geometry.Vector

#### Returns:

nx.geometry.Vector:

### `rotate`

(

- `a`

)
nx.geometry.Line

#### Parameters:

- `a` Number

#### Returns:

nx.geometry.Line:

### `slope`

()

#### Returns:

:

### `squaredLength`

()

#### Returns:

:

### `translate`

(

- `v`

)
mx.math.Line

#### Parameters:

- `v` nx.geometry.Vector

#### Returns:

mx.math.Line: